@@ -25,4 +25,10 @@ def send_event(signal, **kwargs):
 
 class SendEventSerializerMixin:
     def send_event(self, event, **kwargs):
-        send_event(event, sender=self.context["mutation"], **kwargs)  # noqa
+        send_event(
+            event,
+            sender=self.context["mutation"],
+            user=self.context["request"].user,
+            context=getattr(self, "context_data", None),
+            **kwargs,
+        )  # noqa
