@@ -2,7 +2,7 @@ from simple_history.utils import bulk_create_with_history
 
 from ..caluma_form.models import Document
 from . import models
-from .jexl import GroupJexl
+from .jexl import FlowJexl, GroupJexl
 
 
 def get_group_jexl_structure(work_item_created_by_group, case, prev_work_item=None):
@@ -17,7 +17,9 @@ def get_group_jexl_structure(work_item_created_by_group, case, prev_work_item=No
     }
 
 
-def get_jexl_groups(jexl, task, case, work_item_created_by_user, prev_work_item=None):
+def get_jexl_groups(
+    jexl, task, case, work_item_created_by_user, prev_work_item=None, context=None
+):
     if jexl:
         return GroupJexl(
             validation_context=get_group_jexl_structure(
@@ -27,13 +29,31 @@ def get_jexl_groups(jexl, task, case, work_item_created_by_user, prev_work_item=
             case=case,
             work_item_created_by_user=work_item_created_by_user,
             prev_work_item=prev_work_item,
+            dynamic_context=context,
         ).evaluate(jexl)
 
     return []
 
 
-def bulk_create_work_items(tasks, case, user, prev_work_item=None):
+def get_jexl_tasks(jexl, case, user, prev_work_item, context=None):
+    if jexl:
+        evaluated = FlowJexl(
+            case=case, user=user, prev_work_item=prev_work_item, dynamic_context=context
+        ).evaluate(jexl)
+
+        if not isinstance(evaluated, list):
+            evaluated = [evaluated]
+
+        return evaluated
+
+    return []
+
+
+def bulk_create_work_items(
+    tasks, case, user, prev_work_item=None, context: dict = None
+):
     work_items = []
+
     for task in tasks:
         controlling_groups = get_jexl_groups(
             task.control_groups,
@@ -41,6 +61,7 @@ def bulk_create_work_items(tasks, case, user, prev_work_item=None):
             case,
             user,
             prev_work_item if prev_work_item else None,
+            context,
         )
         addressed_groups = [
             get_jexl_groups(
@@ -49,6 +70,7 @@ def bulk_create_work_items(tasks, case, user, prev_work_item=None):
                 case,
                 user,
                 prev_work_item if prev_work_item else None,
+                context,
             )
         ]
         if task.is_multiple_instance:
@@ -66,6 +88,7 @@ def bulk_create_work_items(tasks, case, user, prev_work_item=None):
                     status=models.WorkItem.STATUS_READY,
                     created_by_user=user.username,
                     created_by_group=user.group,
+                    previous_work_item=prev_work_item if prev_work_item else None,
                 )
             )
 
